@@ -190,6 +190,9 @@ class Environment(Environment):
                 pass
 
         for app_path, mod_path in mod_list:
+            if not os.path.isdir(mod_path):
+                continue
+                
             for filename in filter(lambda x: x.endswith(".py"), os.listdir(mod_path)):
                 if filename == '__init__.py':
                     continue
@@ -229,7 +232,8 @@ class Environment(Environment):
 
 initial_params = {
     'autoescape': JINJA2_AUTOESCAPE,
-    'loader': FileSystemLoader(app_directories.app_template_dirs + tuple(settings.TEMPLATE_DIRS)),
+    'loader': FileSystemLoader(tuple(settings.TEMPLATE_DIRS) +
+                               app_directories.app_template_dirs),
     'extensions': list(set(list(JINJA2_EXTENSIONS) + DEFAULT_EXTENSIONS)),
 }
 
